pub enum NbsError {
InvalidFormat,
InvalidString(FromUtf8Error),
IoError(Error),
}Variants
InvalidFormat
This error occures when the format does not contain the expected data
InvalidString(FromUtf8Error)
This error occurs when decoding a string thats not utf-8
IoError(Error)
This error occures when an io operation fails