Layer

Struct Layer 

pub struct Layer {
    pub name: String,
    pub locked: Option<bool>,
    pub volume: i8,
    pub stereo: Option<i8>,
    pub notes: HashMap<i16, Note>,
}
A Layer contains an list of notes and some additional information.

Fields

name: String

Name of the layer.

locked: Option<bool>

Only avabile in the new format version 4.

volume: i8

Layer volume.

stereo: Option<i8>

Only avabile in the new format since version 2.

notes: HashMap<i16, Note>

Implementations

Source

impl Layer

pub fn new() -> Self

Creates an new empty Layer.

pub fn from_format(format: NbsFormat) -> Self

Creates an new Layer with default values for the specified format