[][src]Enum nbs::error::NbsError

pub enum NbsError {
    InvalidTargetFormat,
    InvalidString(FromUtf8Error),
    IoError(Error),
}

Variants

InvalidTargetFormat

This error occures when the format to encode with expected some information that was not given

InvalidString(FromUtf8Error)

This error occurs when decoding a string thats not utf-8

IoError(Error)

This error occures when an io operation fails