pub struct Header {Show 20 fields
pub vannila_instrument_count: Option<i8>,
pub layer_count: i16,
pub song_name: String,
pub song_author: String,
pub original_song_author: String,
pub song_description: String,
pub song_tempo: i16,
pub auto_saving: bool,
pub auto_saving_duration: i8,
pub time_signature: i8,
pub minutes_spent: i32,
pub left_clicks: i32,
pub right_clicks: i32,
pub noteblocks_added: i32,
pub noteblocks_removed: i32,
pub imported_file_name: String,
pub is_loop: Option<bool>,
pub max_loop_count: Option<i8>,
pub loop_start_tick: Option<i16>,
pub format: NbsFormat,
/* private fields */
}Expand description
The header contains information about the file
Fields
vannila_instrument_count: Option<i8>Amount of default instruments when the song was saved. This is needed to determine at what index custom instruments start. Only avabile in the new format
layer_count: i16The last layer with at least one note block in it, or the last layer that has had its name, volume or stereo changed.
song_name: StringThe name of the song.
The author of the song.
The original author of the song.
song_description: StringThe description of the song.
song_tempo: i16The tempo of the song multiplied by 100.
auto_saving: boolWhether auto-saving has been enabled. As of NBS version 4 this value is still saved to the file, but no longer used in the program.
auto_saving_duration: i8The amount of minutes between each auto-save (if it has been enabled) (1-60). As of NBS version 4 this value is still saved to the file, but no longer used in the program.
time_signature: i8The time signature of the song. If this is 3, then the signature is 3/4. Default is 4. This value ranges from 2-8.
minutes_spent: i32Amount of minutes spent on the project.
left_clicks: i32Amount of times the user has left-clicked.
right_clicks: i32Amount of times the user has right-clicked.
noteblocks_added: i32Amount of times the user has added a note block.
noteblocks_removed: i32The amount of times the user have removed a note block.
imported_file_name: StringIf the song has been imported from a .mid or .schematic file, that file name is stored here (only the name of the file, not the path).
is_loop: Option<bool>Whether looping is on or off. Only avabile in the new format.
max_loop_count: Option<i8>0 = infinite. Other values mean the amount of times the song loops. Only avabile in the new format.
loop_start_tick: Option<i16>Determines which part of the song (in ticks) it loops back to. Only avabile in the new format.
format: NbsFormatNot part of the Header.