[−][src]Struct nbs::noteblocks::layer::Layer
A Layer contains an list of notes and some additional information.
Fields
name: StringName of the layer.
locked: Option<bool>Only avabile in the new format version 4.
volume: Option<i8>Only avabile in the new format since version 2.
stereo: Option<i8>Only avabile in the new format since version 2.
notes: HashMap<i16, Note>Methods
impl Layer[src]
pub fn new() -> Self[src]
Creates an new empty Layer.
pub fn from_format(format: NbsFormat) -> Self[src]
Creates an new Layer with default values for the specified format